<?php
/*
 Plugin Name: LiveAgent
 Plugin URI: http://www.qualityunit.com/liveagent
 Description: Plugin enables integration of Wordpress with LiveAgent
 Author: QualityUnit
 Version: 4.2.3
 Author URI: http://www.qualityunit.com/
 License: GPL3 - http://gplv3.fsf.org/
 */
if (!defined('LIVEAGENT_PLUGIN_VERSION')) {
    define('LIVEAGENT_PLUGIN_VERSION', '4.2.3');
}
if (!defined('LIVEAGENT_PLUGIN_NAME')) {
    define('LIVEAGENT_PLUGIN_NAME', 'liveagent');
}

include_once WP_PLUGIN_DIR . DIRECTORY_SEPARATOR . LIVEAGENT_PLUGIN_NAME . DIRECTORY_SEPARATOR . 'Config.php';

$liveagentloadErrorMessage = null;
if (!function_exists('liveagent_PluginLoadError')) {

    function liveagent_PluginLoadError() {
        global $liveagentloadErrorMessage;
        if (current_user_can('install_plugins') && current_user_can('manage_options')) {
            echo '<div class="error"><p>' . $liveagentloadErrorMessage . '</p></div>';
        }
    }
}

try {
    include_once WP_PLUGIN_DIR . DIRECTORY_SEPARATOR . LIVEAGENT_PLUGIN_NAME . DIRECTORY_SEPARATOR . 'Loader.php';
    $liveagentLoader = liveagent_Loader::getInstance();
    $liveagentLoader->load();
} catch (Exception $e) {
    $liveagentloadErrorMessage = sprintf(__('Critical error during %s plugin load %s', LIVEAGENT_PLUGIN_NAME), LIVEAGENT_PLUGIN_NAME, $e->getMessage());
    add_action('admin_notices', 'liveagent_PluginLoadError');
    return;
}

if (!class_exists(LIVEAGENT_PLUGIN_NAME)) {
    class liveagent extends liveagent_Base {

        /**
         * @var liveagent
         */
        private static $instance = null;

        /**
         * @var liveagent_Settings
         */
        private $settings;

        /**
         * @var boolean
         */
        private $active = false;

        public function activate() {
            if ($this->isActive()) {
                return;
            }
            $this->settings = new liveagent_Settings();

            $this->initPlugin();
            $this->active = true;
        }

        public function isActive() {
            return $this->active;
        }

        public static function getInstance() {
            if (self::$instance == null) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /**
         * calledby add_filter ('admin_head', array($this, 'initAdminHeader'), 99);
         */
        public function adminInit() {
            $this->settings->initSettingsForAdminPanel();
        }

        private function accountIsValid() {
            return $this->settings->getAccountStatus() != liveagent_Settings::ACCOUNT_STATUS_NOTSET && $this->settings->getAccountStatus() != liveagent_Settings::ACCOUNT_STATUS_CREATING && $this->settings->getOwnerEmail() != '' && $this->settings->getApiKey() != '' && $this->settings->getLiveAgentUrl() != '';
        }

        private function initFrontend() {
            if (!$this->accountIsValid()) {
                return;
            }
            add_filter('wp_footer', array(
                    $this,
                    'initFooter'
            ), 99);
        }

        private function initPlugin() {
            add_action('admin_init', array(
                    $this,
                    'adminInit'
            ));
            if (!is_admin()) {
                $this->initFrontend();
                return;
            }
            add_filter('plugin_action_links_' . plugin_basename(__FILE__), array(
                    $this,
                    'addSettingsLinkIntoPlugin'
            ));
            add_action('admin_menu', array(
                    $this,
                    'addPrimaryConfigMenu'
            ));
            add_filter('admin_head', array(
                    $this,
                    'initAdminHeader'
            ), 99);
            add_action('wp_enqueue_scripts', array(
                    $this,
                    'includeJavascripts'
            ));
            add_action('admin_enqueue_scripts', array(
                    $this,
                    'includeJavascripts'
            ));
            add_action('in_admin_footer', array(
                    $this,
                    'addButtonToAdminFooter'
            ));
            add_action('plugins_loaded', array(
                    $this,
                    'loadTranslations'
            ));
        }

        private function importTranslationsToJavascript() {
            $translation_array = array(
                    'installing' => __('Installing', LIVEAGENT_PLUGIN_NAME),
                    'justFewMoreSeconds' => __('Just a few more seconds', LIVEAGENT_PLUGIN_NAME),
                    'completing' => __('Installation completed. Setting up...', LIVEAGENT_PLUGIN_NAME),
                    'youSureResetAccount' => __('Are you sure you want to cancel your account?', LIVEAGENT_PLUGIN_NAME)
            );
            wp_localize_script('liveagent-main', 'liveagentLocalizations', $translation_array);
        }

        public function includeJavascripts() {
            wp_enqueue_script('liveagent-alphanum', $this->getJsUrl() . 'jquery.alphanum.js', array(), LIVEAGENT_PLUGIN_VERSION);
            wp_enqueue_script('liveagent-la', $this->getJsUrl() . 'lasignup.js', array(), LIVEAGENT_PLUGIN_VERSION);
            wp_enqueue_script('liveagent-lacrm', $this->getJsUrl() . 'crm_lasignup.js', array(), LIVEAGENT_PLUGIN_VERSION);

            $this->importTranslationsToJavascript();
        }

        public function initAdminHeader($content) {
            if (!is_feed()) {
                echo $this->getStylesheetHeaderLink('style.css');
                echo $this->getStylesheetHeaderLink('animation.css');
                echo $this->getStylesheetHeaderLink('responsive.css');
            }
            echo $content;
        }

        public function addSettingsLinkIntoPlugin($links) {
            return array_merge($links, array('<a href="'.admin_url('admin.php?page='.liveagent_Form_Handler::TOP_LEVEL_OPTIONS_HANDLE).'">Settings</a>'));
        }

        public function loadTranslations() {
            load_plugin_textdomain(LIVEAGENT_PLUGIN_NAME, false, dirname(plugin_basename(__FILE__)) . '/resources/languages/');
        }

        public function addButtonToAdminFooter($content) {
            if (!is_feed()) {
                if ($this->settings->isAdminPreviewEnabled()) {
                    echo $this->settings->replacePlaceholders($this->settings->getButtonCode());
                }
            }
        }

        public function initFooter() {
            if (!is_feed()) {
                try {
                    echo $this->settings->replacePlaceholders($this->settings->getButtonCode());
                } catch (Exception $e) {
                    $this->_log(sprintf('Unable to insert button in footer %s', $e->getMessage()));
                }
            }
        }

        public function addPrimaryConfigMenu() {
            $formHandler = new liveagent_Form_Handler($this->settings);
            add_menu_page(__('LiveAgent', LIVEAGENT_PLUGIN_NAME), __('LiveAgent', LIVEAGENT_PLUGIN_NAME), 'manage_options', liveagent_Form_Handler::TOP_LEVEL_OPTIONS_HANDLE, array(
                    $formHandler,
                    'printPrimaryPage'
            ), $this->getImgUrl() . 'menu-icon.png');
        }
    }
}

register_activation_hook(__FILE__, array(
        'liveagent',
        'install'
));

$liveagent = liveagent::getInstance();
$liveagent->activate();